@@ -1,3 +1,6 @@
+# !/usr/bin/env python
+# -*- coding: utf-8 -*-
+
 """
 sentry_wechat.models
 ~~~~~~~~~~~~~~~~~~~~~
@@ -7,14 +10,11 @@ sentry_wechat.models
 
 import json
 import requests
-from datetime import datetime
-from pytz import timezone
 from sentry.plugins.bases.notify import NotificationPlugin
 import sentry_wechat
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 
-
 class WechatForm(forms.Form):
    urls = forms.CharField(
         label=_('Wechat robot url'),
@@ -51,40 +51,71 @@ class WechatPlugin(NotificationPlugin):
         """
         Check if plugin is configured.
         """
-        return bool(self.get_option('key', project))
+        return bool(self.get_option('urls', project))
 
     def notify_users(self, group, event, *args, **kwargs):
-        self.post_process(group, event, *args, **kwargs)
+        if not self.is_configured(group.project):
+            self.logger.info('wechat urls config error')
+            return None
+
+        if self.should_notify(group, event):
+            self.logger.info('send msg to wechat robot yes')
+            self.post_process(group, event, *args, **kwargs)
+
+        else:
+            self.logger.info('send msg to wechat robot no')
+            return None
 
     def post_process(self, group, event, *args, **kwargs):
         """
         Process error.
         """
-        if not self.is_configured(group.project):
-            return
-
-        if group.is_ignored():
-            return
-
         send_url = self.get_webhook_urls(group.project)
-        title = "[{}]出bug了，快去瞧瞧!".format(event.project.slug)
+        title = "[{}]发生错误，请尽快查看处理!".format(event.project.slug)
+        description = event.title or event.message
         url="{}events/{}/".format(group.get_absolute_url(),event.event_id)
-        description="[{}]{}".format(datetime.now(timezone('Asia/Shanghai')).strftime("%Y-%m-%d %H:%M:%S"),event.title or event.message)
+
         data = {
           "msgtype": "news",
-            "news": {
-            "articles" : [
-                {
-                    "title" : title,
-                    "description" : description,
-                    "url" : url,
-                    "picurl" : "https://i.loli.net/2020/04/28/xZqCELKHhBSeY9t.png"
+                "news": {
+                "articles" : [
+                        {
+                            "title" : title,
+                            "url" : url,
+                            "picurl" : "https://i.loli.net/2020/04/28/xZqCELKHhBSeY9t.png"
+                        }
+                    ]
                 }
-                ]
-            }
         }
+
         requests.post(
             url=send_url,
             headers={"Content-Type": "application/json"},
             data=json.dumps(data)
         )
+
+        main_data = {
+                "msgtype": "markdown",
+                "markdown": {
+                    "content": u"#### {title} \n > 环境: <font color=\"info\">{environment}</font> \n > 等级: <font color=\"warning\">{level}</font> \n > 版本: <font color=\"comment\">{release}</font> \n > 浏览器: <font color=\"comment\">{browser}</font> \n > 操作系统: <font color=\"comment\">{os}</font> \n > 域名: <font color=\"comment\">{domain}</font> \n > 用户: <font color=\"comment\">{user}</font> \n > 报错信息: <font color=\"comment\">{message}</font> \n > 触发点: <font color=\"comment\">{culprit}</font> \n > 创建日期: <font color=\"comment\">{dateCreated}</font> \n > [怼我看BUG!]({url})".format(
+                        title="详情",
+                        environment=event.get_tag("environment"),
+                        level=event.get_tag("level"),
+                        release=event.get_tag("release"),
+                        browser=event.get_tag("browser"),
+                        os=event.get_tag("os"),
+                        domain=event.get_tag("url"),
+                        user=event.get_tag("user"),
+                        message=description,
+                        culprit=event.culprit,
+                        dateCreated=event.dateCreated,
+                        url=url,
+                    )
+                }
+        }
+
+        requests.post(
+            url=send_url,
+            headers={"Content-Type": "application/json"},
+            data=json.dumps(main_data)
+        )
\ No newline at end of file
